@@ -20,12 +20,6 @@ public class IgnoreDependencyQuestions {
         {"org.apache.geronimo.specs", "geronimo-jaxb_2.1_spec"},
         {"org.apache.geronimo.specs", "geronimo-jaxb_2.2_spec"},
         {"jaxb", "jsr173_api"},
-        // Java Activation Framework (added to Java 6)
-        {"activation", "activation"},
-        {"javax.activation", "activation"},
-        {"jaf", "activation"},
-        {"org.apache.geronimo.specs", "geronimo-activation_1.0.2_spec"},
-        {"org.apache.geronimo.specs", "geronimo-activation_1.1_spec"},
         // JMX (added to Java 5)
         {"mx4j", "mx4j"},
         {"mx4j", "mx4j-jmx"},
@@ -41,6 +35,7 @@ public class IgnoreDependencyQuestions {
         {"org.apache.maven.plugins", "maven-archetype-plugin"},
         {"org.apache.maven.plugins", "changelog-maven-plugin"},
         {"org.apache.maven.plugins", "maven-deploy-plugin"},
+        {"org.apache.maven.plugins", "maven-docck-plugin"},
         {"org.apache.maven.plugins", "maven-doap-plugin"},
         {"org.apache.maven.plugins", "maven-release-plugin"},
         {"org.apache.maven.plugins", "maven-repository-plugin"},
@@ -56,9 +51,11 @@ public class IgnoreDependencyQuestions {
         {"org.codehaus.mojo", "nbm-maven-plugin"},
         {"org.codehaus.mojo", "ideauidesigner-maven-plugin"},
         {"org.codehaus.mojo", "scmchangelog-maven-plugin"},
+        {"com.coveo", "fmt-maven-plugin"},
         {"com.github.github", "site-maven-plugin"},
         {"com.googlecode.maven-gcu-plugin", "maven-gcu-plugin"},
         {"org.sonatype.plugins", "nexus-staging-maven-plugin"},
+        {"org.sonatype.ossindex.maven", "ossindex-maven-plugin"},
         {"org.eluder.coveralls", "coveralls-maven-plugin"},
     };
 
@@ -78,6 +75,7 @@ public class IgnoreDependencyQuestions {
         {"org.codehaus.mojo", "dbunit-maven-plugin"},
         {"org.codehaus.mojo", "failsafe-maven-plugin"},
         {"org.codehaus.mojo", "shitty-maven-plugin"},
+        {"org.glassfish.copyright", "glassfish-copyright-maven-plugin"},
         {"com.mycila.maven-license-plugin", "maven-license-plugin"},
         {"com.google.code.maven-license-plugin", "maven-license-plugin"},
     };
@@ -87,7 +85,6 @@ public class IgnoreDependencyQuestions {
         {"org.apache.maven.plugins", "maven-changes-plugin"},
         {"org.apache.maven.plugins", "maven-checkstyle-plugin"},
         {"org.apache.maven.plugins", "maven-clover-plugin"},
-        {"org.apache.maven.plugins", "maven-docck-plugin"},
         {"org.apache.maven.plugins", "maven-javadoc-plugin"},
         {"org.apache.maven.plugins", "maven-jxr-plugin"},
         {"org.apache.maven.plugins", "maven-pmd-plugin"},
